summaryrefslogtreecommitdiff
path: root/gdb/c-valprint.c
diff options
context:
space:
mode:
authorPierre Muller <muller@ics.u-strasbg.fr>2009-10-06 22:47:18 +0000
committerPierre Muller <muller@ics.u-strasbg.fr>2009-10-06 22:47:18 +0000
commitada4a1e8ae6e4b9c279dd965b3cf9219ee67455b (patch)
tree13993403d203e348264c6f86da5178b70206d150 /gdb/c-valprint.c
parent56729ce32e554ad6bdcbd18790c35439f1cdb06b (diff)
downloadgdb-ada4a1e8ae6e4b9c279dd965b3cf9219ee67455b.tar.gz
ARI fix: OP eol rule.
* blockframe.c (find_pc_partial_function): Avoid operator at end of line. * buildsym.c (find_symbol_in_list): Idem. (start_subfile, patch_subfile_names): Idem. * c-exp.y (variable, yylex): Idem. * c-typeprint.c (c_print_type, c_type_print_base): Idem. * c-valprint.c (c_val_print): Idem. * coffread.c (patch_opaque_types, process_coff_symbol): Idem. * corelow.c (core_open): Idem. * cris-tdep.c (move_reg_to_mem_movem_op): Idem. * cli/cli-decode.c (help_cmd_list, find_command_name_length): Idem.
Diffstat (limited to 'gdb/c-valprint.c')
-rw-r--r--gdb/c-valprint.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/gdb/c-valprint.c b/gdb/c-valprint.c
index dc391ee2244..e6fbffe61c4 100644
--- a/gdb/c-valprint.c
+++ b/gdb/c-valprint.c
@@ -54,7 +54,7 @@ print_function_pointer_address (struct gdbarch *gdbarch, CORE_ADDR address,
}
/* A helper for textual_element_type. This checks the name of the
typedef. This is bogus but it isn't apparent that the compiler
provides us the help we may need. */
@@ -77,8 +77,8 @@ textual_name (const char *name)
vector types is not. The user can override this by using the /s
format letter. */
-static int
-textual_element_type (struct type *type, char format)
+int
+c_textual_element_type (struct type *type, char format)
{
struct type *true_type, *iter_type;
@@ -178,7 +178,7 @@ c_val_print (struct type *type, const gdb_byte *valaddr, int embedded_offset,
}
/* Print arrays of textual chars with a string syntax. */
- if (textual_element_type (unresolved_elttype, options->format))
+ if (c_textual_element_type (unresolved_elttype, options->format))
{
/* If requested, look for the first null char and only print
elements up to it. */
@@ -278,7 +278,7 @@ c_val_print (struct type *type, const gdb_byte *valaddr, int embedded_offset,
/* For a pointer to a textual type, also print the string
pointed to, unless pointer is null. */
- if (textual_element_type (unresolved_elttype, options->format)
+ if (c_textual_element_type (unresolved_elttype, options->format)
&& addr != 0)
{
i = val_print_string (unresolved_elttype, addr, -1, stream,
@@ -291,8 +291,8 @@ c_val_print (struct type *type, const gdb_byte *valaddr, int embedded_offset,
struct minimal_symbol *msymbol =
lookup_minimal_symbol_by_pc (vt_address);
- if ((msymbol != NULL) &&
- (vt_address == SYMBOL_VALUE_ADDRESS (msymbol)))
+ if ((msymbol != NULL)
+ && (vt_address == SYMBOL_VALUE_ADDRESS (msymbol)))
{
fputs_filtered (" <", stream);
fputs_filtered (SYMBOL_PRINT_NAME (msymbol), stream);
@@ -491,7 +491,7 @@ c_val_print (struct type *type, const gdb_byte *valaddr, int embedded_offset,
Since we don't know whether the value is really intended to
be used as an integer or a character, print the character
equivalent as well. */
- if (textual_element_type (unresolved_type, options->format))
+ if (c_textual_element_type (unresolved_type, options->format))
{
fputs_filtered (" ", stream);
LA_PRINT_CHAR ((unsigned char) unpack_long (type, valaddr + embedded_offset),
@@ -613,7 +613,7 @@ c_value_print (struct value *val, struct ui_file *stream,
{
/* Hack: remove (char *) for char strings. Their
type is indicated by the quoted string anyway.
- (Don't use textual_element_type here; quoted strings
+ (Don't use c_textual_element_type here; quoted strings
are always exactly (char *), (wchar_t *), or the like. */
if (TYPE_CODE (val_type) == TYPE_CODE_PTR
&& TYPE_NAME (val_type) == NULL
@@ -54,7 +54,7 @@ print_function_pointer_address (struct gdbarch *gdbarch, CORE_ADDR address,
}
-/* A helper for textual_element_type. This checks the name of the
+/* A helper for c_textual_element_type. This checks the name of the
typedef. This is bogus but it isn't apparent that the compiler
provides us the help we may need. */